@@ -16,8 +16,8 @@ import threading
 # import _thread  使用_thread会报错，坑！
 
 
-__versinon__ = '1.3.3'
-__last_modified__ = '2023/8/20'
+__versinon__ = '1.3.6'
+__last_modified__ = '2023/9/5'
 
 GPIO.setwarnings(False)
 GPIO.setmode(GPIO.BCM)
@@ -179,7 +179,7 @@ class XGOEDU():
     '''
     x1,y1,x2,y2为定义给定边框的两个点,angle0为初始角度,angle1为终止角度
     '''
-    def lcd_arc(self,x1,y1,x2,y2,angle0,angle1,color="WHITE",width=2):
+    def lcd_circle(self,x1,y1,x2,y2,angle0,angle1,color="WHITE",width=2):
         self.draw.arc((x1,y1,x2,y2),angle0,angle1,fill=color ,width=width)
         self.display.ShowImage(self.splash)
 
@@ -189,7 +189,7 @@ class XGOEDU():
     radius 圆半径长度 mm
     
     '''
-    def lcd_circle(self,center_x, center_y, radius, color, width=2):
+    def lcd_round(self,center_x, center_y, radius, color, width=2):
         # Calculate the bounding box for the circle
         x1 = center_x - radius
         y1 = center_y - radius
@@ -197,7 +197,7 @@ class XGOEDU():
         y2 = center_y + radius
     
         # Call lcd_circle() function to draw the circle
-        self.lcd_arc(x1, y1, x2, y2, 0, 360, color=color, width=width)
+        self.lcd_circle(x1, y1, x2, y2, 0, 360, color=color, width=width)
   
 
     
@@ -236,9 +236,7 @@ class XGOEDU():
     x1,y1为初始点坐标,content为内容
     遇到回车符自动换行，遇到边缘换行，一页满了自动清屏，2,2开始继续显示
     '''
-    def display_text_on_screen(content, color, start_x=2, start_y=2, font_size=20, screen_width=320, screen_height=240):
-        XGO_edu = XGOEDU()  # 实例化edu
-    
+    def display_text_on_screen(self, content, color, start_x=2, start_y=2, font_size=20, screen_width=320, screen_height=240):
         # 计算每行可显示字符的数量和行数
         char_width = font_size +1  #// 2
         chars_per_line = screen_width // char_width
@@ -292,11 +290,11 @@ class XGOEDU():
                         current_y = start_y + current_line * char_width # font_size
                         current_line +=1
                        
-                        XGO_edu.lcd_text(current_x, current_y, char, color, font_size)
+                        self.lcd_text(current_x, current_y, char, color, font_size)
                         current_char += 1
                         break  # continue
     
-                    lcd_text(current_x, current_y, char, color, font_size)
+                    self.lcd_text(current_x, current_y, char, color, font_size)
                     current_x += char_width
                     current_char += 1
     
@@ -632,10 +630,10 @@ class XGOEDU():
             success,image = self.cap.read()
         else:
             image=np.array(Image.open(target))
+        image = cv2.flip(image,1)
         datas = self.hand.run(image)
         b,g,r = cv2.split(image)
         image = cv2.merge((r,g,b))
-        #image = cv2.flip(image,1)
         for data in datas:
             rect = data['rect']
             right_left = data['right_left']
@@ -1436,4 +1434,4 @@ class face_detection():
             'right_ear':(int(keypoint4.x),int(keypoint4.y)),
             'left_ear':(int(keypoint5.x),int(keypoint5.y)),
             }
-        return data
\ No newline at end of file
+        return data
